@@ -16,3 +16,7 @@ class TestSelector(unittest.TestCase):
 
         task.report("model-1", {"score": 1.0, "fit-time": 1.0})
         assert selector.propose() == "model-1"
+
+        for _ in range(10):
+            model = selector.propose()
+            task.report(model, {"score": 1.0, "fit-time": 1.0})
